using System;
using System.Collections.Generic;
using System.Data;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace CallCenterApi.BLL
{
    /// <summary>
	/// 回访任务分配表
	/// </summary>
	public partial class T_Vis_TelAllot
    {
        private readonly DAL.T_Vis_TelAllot dal = new DAL.T_Vis_TelAllot();
        public T_Vis_TelAllot()
        { }
        #region  BasicMethod
        /// <summary>
        /// 是否存在该记录
        /// </summary>
        public bool Exists(int F_AllotID)
        {
            return dal.Exists(F_AllotID);
        }

        /// <summary>
        /// 增加一条数据
        /// </summary>
        public int Add(Model.T_Vis_TelAllot model)
        {
            return dal.Add(model);
        }

        /// <summary>
        /// 更新一条数据
        /// </summary>
        public bool Update(Model.T_Vis_TelAllot model)
        {
            return dal.Update(model);
        }

        /// <summary>
        /// 删除一条数据
        /// </summary>
        public bool Delete(int F_AllotID)
        {

            return dal.Delete(F_AllotID);
        }
        /// <summary>
        /// 删除一条数据
        /// </summary>
        public bool DeleteList(string F_AllotIDlist)
        {
            return dal.DeleteList(F_AllotIDlist);
        }

        /// <summary>
        /// 得到一个对象实体
        /// </summary>
        public Model.T_Vis_TelAllot GetModel(int F_AllotID)
        {

            return dal.GetModel(F_AllotID);
        }

        /// <summary>
        /// 获得数据列表
        /// </summary>
        public DataSet GetList(string strWhere)
        {
            return dal.GetList(strWhere);
        }
        /// <summary>
        /// 获得前几行数据
        /// </summary>
        public DataSet GetList(int Top, string strWhere, string filedOrder)
        {
            return dal.GetList(Top, strWhere, filedOrder);
        }
        /// <summary>
        /// 获得数据列表
        /// </summary>
        public List<Model.T_Vis_TelAllot> GetModelList(string strWhere)
        {
            DataSet ds = dal.GetList(strWhere);
            return DataTableToList(ds.Tables[0]);
        }
        /// <summary>
        /// 获得数据列表
        /// </summary>
        public List<Model.T_Vis_TelAllot> DataTableToList(DataTable dt)
        {
            List<Model.T_Vis_TelAllot> modelList = new List<Model.T_Vis_TelAllot>();
            int rowsCount = dt.Rows.Count;
            if (rowsCount > 0)
            {
                Model.T_Vis_TelAllot model;
                for (int n = 0; n < rowsCount; n++)
                {
                    model = dal.DataRowToModel(dt.Rows[n]);
                    if (model != null)
                    {
                        modelList.Add(model);
                    }
                }
            }
            return modelList;
        }

        /// <summary>
        /// 获得数据列表
        /// </summary>
        public DataSet GetAllList()
        {
            return GetList("");
        }

        /// <summary>
        /// 分页获取数据列表
        /// </summary>
        public int GetRecordCount(string strWhere)
        {
            return dal.GetRecordCount(strWhere);
        }
        /// <summary>
        /// 分页获取数据列表
        /// </summary>
        public DataSet GetListByPage(string strWhere, string orderby, int startIndex, int endIndex)
        {
            return dal.GetListByPage(strWhere, orderby, startIndex, endIndex);
        }

        #endregion  BasicMethod
        #region  ExtensionMethod
        public bool UpdateFP(int id, int zxid, string zxname, int userid, string username)
        {
            return dal.UpdateFP(id, zxid, zxname, userid, username);
        }

        #endregion  ExtensionMethod
    }
}
